"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
const unmarshalContactPointEmail = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContactPointEmail' failed as data isn't a dictionary.`
    );
  }
  return {
    to: data.to
  };
};
const unmarshalContactPoint = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ContactPoint' failed as data isn't a dictionary.`
    );
  }
  return {
    email: data.email ? unmarshalContactPointEmail(data.email) : void 0,
    region: data.region
  };
};
const unmarshalDataSource = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'DataSource' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    origin: data.origin,
    projectId: data.project_id,
    region: data.region,
    synchronizedWithGrafana: data.synchronized_with_grafana,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    url: data.url
  };
};
const unmarshalGrafanaProductDashboard = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'GrafanaProductDashboard' failed as data isn't a dictionary.`
    );
  }
  return {
    name: data.name,
    tags: data.tags,
    title: data.title,
    url: data.url,
    variables: data.variables
  };
};
const unmarshalGrafanaUser = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'GrafanaUser' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    login: data.login,
    password: data.password,
    role: data.role
  };
};
const unmarshalPlan = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Plan' failed as data isn't a dictionary.`
    );
  }
  return {
    logsIngestionPrice: data.logs_ingestion_price,
    monthlyPrice: data.monthly_price,
    name: data.name,
    retentionLogsInterval: data.retention_logs_interval,
    retentionMetricsInterval: data.retention_metrics_interval,
    retentionTracesInterval: data.retention_traces_interval,
    sampleIngestionPrice: data.sample_ingestion_price,
    tracesIngestionPrice: data.traces_ingestion_price
  };
};
const unmarshalToken = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Token' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    projectId: data.project_id,
    region: data.region,
    scopes: data.scopes,
    secretKey: data.secret_key,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalAlertManager = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'AlertManager' failed as data isn't a dictionary.`
    );
  }
  return {
    alertManagerEnabled: data.alert_manager_enabled,
    alertManagerUrl: data.alert_manager_url,
    managedAlertsEnabled: data.managed_alerts_enabled,
    region: data.region
  };
};
const unmarshalGrafana = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Grafana' failed as data isn't a dictionary.`
    );
  }
  return {
    grafanaUrl: data.grafana_url
  };
};
const unmarshalListContactPointsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListContactPointsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    contactPoints: marshalling.unmarshalArrayOfObject(
      data.contact_points,
      unmarshalContactPoint
    ),
    hasAdditionalContactPoints: data.has_additional_contact_points,
    hasAdditionalReceivers: data.has_additional_receivers,
    totalCount: data.total_count
  };
};
const unmarshalListDataSourcesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListDataSourcesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    dataSources: marshalling.unmarshalArrayOfObject(data.data_sources, unmarshalDataSource),
    totalCount: data.total_count
  };
};
const unmarshalListGrafanaProductDashboardsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListGrafanaProductDashboardsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    dashboards: marshalling.unmarshalArrayOfObject(
      data.dashboards,
      unmarshalGrafanaProductDashboard
    ),
    totalCount: data.total_count
  };
};
const unmarshalListGrafanaUsersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListGrafanaUsersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    grafanaUsers: marshalling.unmarshalArrayOfObject(
      data.grafana_users,
      unmarshalGrafanaUser
    ),
    totalCount: data.total_count
  };
};
const unmarshalListPlansResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPlansResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    plans: marshalling.unmarshalArrayOfObject(data.plans, unmarshalPlan),
    totalCount: data.total_count
  };
};
const unmarshalListTokensResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListTokensResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    tokens: marshalling.unmarshalArrayOfObject(data.tokens, unmarshalToken),
    totalCount: data.total_count
  };
};
const unmarshalUsage = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Usage' failed as data isn't a dictionary.`
    );
  }
  return {
    dataSourceId: data.data_source_id,
    dataSourceOrigin: data.data_source_origin,
    dataSourceType: data.data_source_type,
    interval: data.interval,
    projectId: data.project_id,
    quantityOverInterval: data.quantity_over_interval,
    region: data.region,
    unit: data.unit
  };
};
const unmarshalUsageOverview = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'UsageOverview' failed as data isn't a dictionary.`
    );
  }
  return {
    externalLogsUsage: data.external_logs_usage ? unmarshalUsage(data.external_logs_usage) : void 0,
    externalMetricsUsage: data.external_metrics_usage ? unmarshalUsage(data.external_metrics_usage) : void 0,
    externalTracesUsage: data.external_traces_usage ? unmarshalUsage(data.external_traces_usage) : void 0,
    scalewayLogsUsage: data.scaleway_logs_usage ? unmarshalUsage(data.scaleway_logs_usage) : void 0,
    scalewayMetricsUsage: data.scaleway_metrics_usage ? unmarshalUsage(data.scaleway_metrics_usage) : void 0
  };
};
const marshalGlobalApiCreateGrafanaUserRequest = (request, defaults) => ({
  login: request.login,
  project_id: request.projectId ?? defaults.defaultProjectId,
  role: request.role
});
const marshalGlobalApiResetGrafanaUserPasswordRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalGlobalApiSelectPlanRequest = (request, defaults) => ({
  plan_name: request.planName,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalGlobalApiSyncGrafanaDataSourcesRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalContactPointEmail = (request, defaults) => ({
  to: request.to
});
const marshalRegionalApiCreateContactPointRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([
    {
      param: "email",
      value: request.email !== void 0 ? marshalContactPointEmail(request.email) : void 0
    }
  ])
});
const marshalRegionalApiCreateDataSourceRequest = (request, defaults) => ({
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId,
  type: request.type
});
const marshalRegionalApiCreateTokenRequest = (request, defaults) => ({
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId,
  token_scopes: request.tokenScopes !== void 0 ? request.tokenScopes : void 0
});
const marshalRegionalApiDeleteContactPointRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId,
  ...marshalling.resolveOneOf([
    {
      param: "email",
      value: request.email !== void 0 ? marshalContactPointEmail(request.email) : void 0
    }
  ])
});
const marshalRegionalApiDisableAlertManagerRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalRegionalApiDisableManagedAlertsRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalRegionalApiEnableAlertManagerRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalRegionalApiEnableManagedAlertsRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalRegionalApiTriggerTestAlertRequest = (request, defaults) => ({
  project_id: request.projectId ?? defaults.defaultProjectId
});
exports.marshalGlobalApiCreateGrafanaUserRequest = marshalGlobalApiCreateGrafanaUserRequest;
exports.marshalGlobalApiResetGrafanaUserPasswordRequest = marshalGlobalApiResetGrafanaUserPasswordRequest;
exports.marshalGlobalApiSelectPlanRequest = marshalGlobalApiSelectPlanRequest;
exports.marshalGlobalApiSyncGrafanaDataSourcesRequest = marshalGlobalApiSyncGrafanaDataSourcesRequest;
exports.marshalRegionalApiCreateContactPointRequest = marshalRegionalApiCreateContactPointRequest;
exports.marshalRegionalApiCreateDataSourceRequest = marshalRegionalApiCreateDataSourceRequest;
exports.marshalRegionalApiCreateTokenRequest = marshalRegionalApiCreateTokenRequest;
exports.marshalRegionalApiDeleteContactPointRequest = marshalRegionalApiDeleteContactPointRequest;
exports.marshalRegionalApiDisableAlertManagerRequest = marshalRegionalApiDisableAlertManagerRequest;
exports.marshalRegionalApiDisableManagedAlertsRequest = marshalRegionalApiDisableManagedAlertsRequest;
exports.marshalRegionalApiEnableAlertManagerRequest = marshalRegionalApiEnableAlertManagerRequest;
exports.marshalRegionalApiEnableManagedAlertsRequest = marshalRegionalApiEnableManagedAlertsRequest;
exports.marshalRegionalApiTriggerTestAlertRequest = marshalRegionalApiTriggerTestAlertRequest;
exports.unmarshalAlertManager = unmarshalAlertManager;
exports.unmarshalContactPoint = unmarshalContactPoint;
exports.unmarshalDataSource = unmarshalDataSource;
exports.unmarshalGrafana = unmarshalGrafana;
exports.unmarshalGrafanaProductDashboard = unmarshalGrafanaProductDashboard;
exports.unmarshalGrafanaUser = unmarshalGrafanaUser;
exports.unmarshalListContactPointsResponse = unmarshalListContactPointsResponse;
exports.unmarshalListDataSourcesResponse = unmarshalListDataSourcesResponse;
exports.unmarshalListGrafanaProductDashboardsResponse = unmarshalListGrafanaProductDashboardsResponse;
exports.unmarshalListGrafanaUsersResponse = unmarshalListGrafanaUsersResponse;
exports.unmarshalListPlansResponse = unmarshalListPlansResponse;
exports.unmarshalListTokensResponse = unmarshalListTokensResponse;
exports.unmarshalPlan = unmarshalPlan;
exports.unmarshalToken = unmarshalToken;
exports.unmarshalUsageOverview = unmarshalUsageOverview;
