import { API as ParentAPI } from '../../../bridge';
import type { WaitForOptions } from '../../../bridge';
import type { ActivateCockpitRequest, Cockpit, CockpitMetrics, ContactPoint, CreateContactPointRequest, CreateDatasourceRequest, CreateGrafanaUserRequest, CreateTokenRequest, Datasource, DeactivateCockpitRequest, DeleteContactPointRequest, DeleteDatasourceRequest, DeleteGrafanaUserRequest, DeleteTokenRequest, DisableManagedAlertsRequest, EnableManagedAlertsRequest, GetCockpitMetricsRequest, GetCockpitRequest, GetGrafanaProductDashboardRequest, GetTokenRequest, GrafanaProductDashboard, GrafanaUser, ListContactPointsRequest, ListContactPointsResponse, ListDatasourcesRequest, ListDatasourcesResponse, ListGrafanaProductDashboardsRequest, ListGrafanaProductDashboardsResponse, ListGrafanaUsersRequest, ListGrafanaUsersResponse, ListPlansRequest, ListPlansResponse, ListTokensRequest, ListTokensResponse, ResetGrafanaUserPasswordRequest, SelectPlanRequest, SelectPlanResponse, Token, TriggerTestAlertRequest } from './types.gen';
/**
 * Cockpit API.
 *
 * This API allows you to manage your Scaleway Cockpit, for storing and
 * visualizing metrics and logs.
 */
export declare class API extends ParentAPI {
    /**
     * Activate the Cockpit of a given Project specified by the Project ID.
     *
     * @param request - The request {@link ActivateCockpitRequest}
     * @returns A Promise of Cockpit
     */
    activateCockpit: (request?: Readonly<ActivateCockpitRequest>) => Promise<Cockpit>;
    /**
     * Retrieve the Cockpit of a given Project specified by the Project ID.
     *
     * @param request - The request {@link GetCockpitRequest}
     * @returns A Promise of Cockpit
     */
    getCockpit: (request?: Readonly<GetCockpitRequest>) => Promise<Cockpit>;
    /**
     * Waits for {@link Cockpit} to be in a final state.
     *
     * @param request - The request {@link GetCockpitRequest}
     * @param options - The waiting options
     * @returns A Promise of Cockpit
     */
    waitForCockpit: (request?: Readonly<GetCockpitRequest>, options?: Readonly<WaitForOptions<Cockpit>>) => Promise<Cockpit>;
    /**
     * Retrieve metrics from your Cockpit specified by the ID of the Project the
     * Cockpit belongs to.
     *
     * @param request - The request {@link GetCockpitMetricsRequest}
     * @returns A Promise of CockpitMetrics
     */
    getCockpitMetrics: (request?: Readonly<GetCockpitMetricsRequest>) => Promise<CockpitMetrics>;
    /**
     * Deactivate the Cockpit of a given Project specified by the Project ID.
     *
     * @param request - The request {@link DeactivateCockpitRequest}
     * @returns A Promise of Cockpit
     */
    deactivateCockpit: (request?: Readonly<DeactivateCockpitRequest>) => Promise<Cockpit>;
    /**
     * Create a data source for a given Project specified by the Project ID and
     * the data source type.
     *
     * @param request - The request {@link CreateDatasourceRequest}
     * @returns A Promise of Datasource
     */
    createDatasource: (request: Readonly<CreateDatasourceRequest>) => Promise<Datasource>;
    /**
     * Delete a given data source specified by the data source ID.
     *
     * @param request - The request {@link DeleteDatasourceRequest}
     */
    deleteDatasource: (request: Readonly<DeleteDatasourceRequest>) => Promise<void>;
    protected pageOfListDatasources: (request?: Readonly<ListDatasourcesRequest>) => Promise<ListDatasourcesResponse>;
    /**
     * Get a list of data sources for the specified Project ID.
     *
     * @param request - The request {@link ListDatasourcesRequest}
     * @returns A Promise of ListDatasourcesResponse
     */
    listDatasources: (request?: Readonly<ListDatasourcesRequest>) => Promise<ListDatasourcesResponse> & {
        all: () => Promise<Datasource[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Datasource[], void, void>;
    };
    /**
     * Create a token in a given Project specified by the Project ID.
     *
     * @param request - The request {@link CreateTokenRequest}
     * @returns A Promise of Token
     */
    createToken: (request?: Readonly<CreateTokenRequest>) => Promise<Token>;
    protected pageOfListTokens: (request?: Readonly<ListTokensRequest>) => Promise<ListTokensResponse>;
    /**
     * Get a list of tokens in a given Project specified by the Project ID.
     *
     * @param request - The request {@link ListTokensRequest}
     * @returns A Promise of ListTokensResponse
     */
    listTokens: (request?: Readonly<ListTokensRequest>) => Promise<ListTokensResponse> & {
        all: () => Promise<Token[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<Token[], void, void>;
    };
    /**
     * Retrieve a given token specified by the token ID.
     *
     * @param request - The request {@link GetTokenRequest}
     * @returns A Promise of Token
     */
    getToken: (request: Readonly<GetTokenRequest>) => Promise<Token>;
    /**
     * Delete a given token specified by the token ID.
     *
     * @param request - The request {@link DeleteTokenRequest}
     */
    deleteToken: (request: Readonly<DeleteTokenRequest>) => Promise<void>;
    /**
     * Create a contact point associated with the default receiver, to receive
     * alerts.
     *
     * @param request - The request {@link CreateContactPointRequest}
     * @returns A Promise of ContactPoint
     */
    createContactPoint: (request?: Readonly<CreateContactPointRequest>) => Promise<ContactPoint>;
    protected pageOfListContactPoints: (request?: Readonly<ListContactPointsRequest>) => Promise<ListContactPointsResponse>;
    /**
     * Get a list of contact points created for a given Cockpit, specified by the
     * ID of the Project the Cockpit belongs to.
     *
     * @param request - The request {@link ListContactPointsRequest}
     * @returns A Promise of ListContactPointsResponse
     */
    listContactPoints: (request?: Readonly<ListContactPointsRequest>) => Promise<ListContactPointsResponse> & {
        all: () => Promise<ContactPoint[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<ContactPoint[], void, void>;
    };
    /**
     * Delete a contact point associated with the default receiver.
     *
     * @param request - The request {@link DeleteContactPointRequest}
     */
    deleteContactPoint: (request?: Readonly<DeleteContactPointRequest>) => Promise<void>;
    /**
     * Enable the sending of managed alerts for a given Cockpit, specified by the
     * ID of the Project the Cockpit belongs to.
     *
     * @param request - The request {@link EnableManagedAlertsRequest}
     */
    enableManagedAlerts: (request?: Readonly<EnableManagedAlertsRequest>) => Promise<void>;
    /**
     * Disable the sending of managed alerts for a given Cockpit, specified by the
     * ID of the Project the Cockpit belongs to.
     *
     * @param request - The request {@link DisableManagedAlertsRequest}
     */
    disableManagedAlerts: (request?: Readonly<DisableManagedAlertsRequest>) => Promise<void>;
    /**
     * Send a test alert to make sure your contact points get notified when an
     * actual alert is triggered.
     *
     * @param request - The request {@link TriggerTestAlertRequest}
     */
    triggerTestAlert: (request?: Readonly<TriggerTestAlertRequest>) => Promise<void>;
    /**
     * Create a Grafana user for your Cockpit's Grafana. Make sure you save the
     * automatically-generated password and the Grafana user ID.
     *
     * @param request - The request {@link CreateGrafanaUserRequest}
     * @returns A Promise of GrafanaUser
     */
    createGrafanaUser: (request: Readonly<CreateGrafanaUserRequest>) => Promise<GrafanaUser>;
    protected pageOfListGrafanaUsers: (request?: Readonly<ListGrafanaUsersRequest>) => Promise<ListGrafanaUsersResponse>;
    /**
     * Get a list of all Grafana users created in your Cockpit's Grafana.
     *
     * @param request - The request {@link ListGrafanaUsersRequest}
     * @returns A Promise of ListGrafanaUsersResponse
     */
    listGrafanaUsers: (request?: Readonly<ListGrafanaUsersRequest>) => Promise<ListGrafanaUsersResponse> & {
        all: () => Promise<GrafanaUser[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<GrafanaUser[], void, void>;
    };
    /**
     * Delete a Grafana user from your Cockpit's Grafana, specified by the ID of
     * the Project the Cockpit belongs to, and the ID of the Grafana user.
     *
     * @param request - The request {@link DeleteGrafanaUserRequest}
     */
    deleteGrafanaUser: (request: Readonly<DeleteGrafanaUserRequest>) => Promise<void>;
    /**
     * Reset the password of a Grafana user, specified by the ID of the Project
     * the Cockpit belongs to, and the ID of the Grafana user.
     *
     * @param request - The request {@link ResetGrafanaUserPasswordRequest}
     * @returns A Promise of GrafanaUser
     */
    resetGrafanaUserPassword: (request: Readonly<ResetGrafanaUserPasswordRequest>) => Promise<GrafanaUser>;
    protected pageOfListPlans: (request?: Readonly<ListPlansRequest>) => Promise<ListPlansResponse>;
    /**
     * Get a list of all pricing plans available.
     *
     * @param request - The request {@link ListPlansRequest}
     * @returns A Promise of ListPlansResponse
     */
    listPlans: (request?: Readonly<ListPlansRequest>) => Promise<ListPlansResponse> & {
        all: () => Promise<import("./types.gen").Plan[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Plan[], void, void>;
    };
    /**
     * Select your chosen pricing plan for your Cockpit, specifying the Cockpit's
     * Project ID and the pricing plan's ID in the request.
     *
     * @param request - The request {@link SelectPlanRequest}
     * @returns A Promise of SelectPlanResponse
     */
    selectPlan: (request: Readonly<SelectPlanRequest>) => Promise<SelectPlanResponse>;
    protected pageOfListGrafanaProductDashboards: (request?: Readonly<ListGrafanaProductDashboardsRequest>) => Promise<ListGrafanaProductDashboardsResponse>;
    /**
     * List product dashboards. Get a list of available product dashboards.
     *
     * @param request - The request {@link ListGrafanaProductDashboardsRequest}
     * @returns A Promise of ListGrafanaProductDashboardsResponse
     */
    listGrafanaProductDashboards: (request?: Readonly<ListGrafanaProductDashboardsRequest>) => Promise<ListGrafanaProductDashboardsResponse> & {
        all: () => Promise<GrafanaProductDashboard[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<GrafanaProductDashboard[], void, void>;
    };
    /**
     * Get a product dashboard. Get a product dashboard specified by the dashboard
     * ID.
     *
     * @param request - The request {@link GetGrafanaProductDashboardRequest}
     * @returns A Promise of GrafanaProductDashboard
     */
    getGrafanaProductDashboard: (request: Readonly<GetGrafanaProductDashboardRequest>) => Promise<GrafanaProductDashboard>;
}
