"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
const unmarshalResource = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Resource' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    macAddress: data.mac_address,
    name: data.name,
    type: data.type
  };
};
const unmarshalReverse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Reverse' failed as data isn't a dictionary.`
    );
  }
  return {
    address: data.address,
    hostname: data.hostname
  };
};
const unmarshalSource = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Source' failed as data isn't a dictionary.`
    );
  }
  return {
    privateNetworkId: data.private_network_id,
    subnetId: data.subnet_id,
    zonal: data.zonal
  };
};
const unmarshalIP = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'IP' failed as data isn't a dictionary.`
    );
  }
  return {
    address: data.address,
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    isIpv6: data.is_ipv6,
    projectId: data.project_id,
    region: data.region,
    resource: data.resource ? unmarshalResource(data.resource) : void 0,
    reverses: marshalling.unmarshalArrayOfObject(data.reverses, unmarshalReverse),
    source: unmarshalSource(data.source),
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    zone: data.zone
  };
};
const unmarshalListIPsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListIPsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    ips: marshalling.unmarshalArrayOfObject(data.ips, unmarshalIP),
    totalCount: data.total_count
  };
};
const marshalSource = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    { param: "zonal", value: request.zonal },
    { param: "private_network_id", value: request.privateNetworkId },
    { param: "subnet_id", value: request.subnetId }
  ])
});
const marshalBookIPRequest = (request, defaults) => ({
  address: request.address,
  is_ipv6: request.isIpv6,
  project_id: request.projectId ?? defaults.defaultProjectId,
  source: marshalSource(request.source),
  tags: request.tags
});
const marshalReleaseIPSetRequest = (request, defaults) => ({
  ip_ids: request.ipIds
});
const marshalReverse = (request, defaults) => ({
  address: request.address,
  hostname: request.hostname
});
const marshalUpdateIPRequest = (request, defaults) => ({
  reverses: request.reverses !== void 0 ? request.reverses.map((elt) => marshalReverse(elt)) : void 0,
  tags: request.tags
});
exports.marshalBookIPRequest = marshalBookIPRequest;
exports.marshalReleaseIPSetRequest = marshalReleaseIPSetRequest;
exports.marshalUpdateIPRequest = marshalUpdateIPRequest;
exports.unmarshalIP = unmarshalIP;
exports.unmarshalListIPsResponse = unmarshalListIPsResponse;
