import { isJSONObject } from "../../../helpers/json.js";
import { unmarshalDate, unmarshalArrayOfObject } from "../../../helpers/marshalling.js";
const unmarshalName = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Name' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    key: data.key,
    name: data.name,
    nameId: data.name_id,
    projectId: data.project_id,
    region: data.region,
    status: data.status,
    tags: data.tags,
    updatedAt: unmarshalDate(data.updated_at),
    value: data.value
  };
};
const unmarshalPinCIDMeta = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PinCIDMeta' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id
  };
};
const unmarshalPinCID = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PinCID' failed as data isn't a dictionary.`
    );
  }
  return {
    cid: data.cid,
    meta: data.meta ? unmarshalPinCIDMeta(data.meta) : void 0,
    name: data.name,
    origins: data.origins
  };
};
const unmarshalPinInfo = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PinInfo' failed as data isn't a dictionary.`
    );
  }
  return {
    id: data.id,
    progress: data.progress,
    size: data.size,
    statusDetails: data.status_details,
    url: data.url
  };
};
const unmarshalPin = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Pin' failed as data isn't a dictionary.`
    );
  }
  return {
    cid: data.cid ? unmarshalPinCID(data.cid) : void 0,
    createdAt: unmarshalDate(data.created_at),
    delegates: data.delegates,
    info: data.info ? unmarshalPinInfo(data.info) : void 0,
    pinId: data.pin_id,
    status: data.status
  };
};
const unmarshalVolume = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Volume' failed as data isn't a dictionary.`
    );
  }
  return {
    countPin: data.count_pin,
    createdAt: unmarshalDate(data.created_at),
    id: data.id,
    name: data.name,
    projectId: data.project_id,
    region: data.region,
    size: data.size,
    tags: data.tags,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalExportKeyNameResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ExportKeyNameResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: unmarshalDate(data.created_at),
    nameId: data.name_id,
    privateKey: data.private_key,
    projectId: data.project_id,
    publicKey: data.public_key,
    updatedAt: unmarshalDate(data.updated_at)
  };
};
const unmarshalListNamesResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListNamesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    names: unmarshalArrayOfObject(data.names, unmarshalName),
    totalCount: data.total_count
  };
};
const unmarshalListPinsResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPinsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pins: unmarshalArrayOfObject(data.pins, unmarshalPin),
    totalCount: data.total_count
  };
};
const unmarshalListVolumesResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListVolumesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    volumes: unmarshalArrayOfObject(data.volumes, unmarshalVolume)
  };
};
const unmarshalReplacePinResponse = (data) => {
  if (!isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ReplacePinResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    pin: data.pin ? unmarshalPin(data.pin) : void 0
  };
};
const marshalCreatePinByCIDRequest = (request, defaults) => ({
  cid: request.cid,
  name: request.name,
  origins: request.origins,
  volume_id: request.volumeId
});
const marshalCreatePinByURLRequest = (request, defaults) => ({
  name: request.name,
  url: request.url,
  volume_id: request.volumeId
});
const marshalCreateVolumeRequest = (request, defaults) => ({
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalIpnsApiCreateNameRequest = (request, defaults) => ({
  name: request.name,
  project_id: request.projectId ?? defaults.defaultProjectId,
  value: request.value
});
const marshalIpnsApiImportKeyNameRequest = (request, defaults) => ({
  name: request.name,
  private_key: request.privateKey,
  project_id: request.projectId ?? defaults.defaultProjectId,
  value: request.value
});
const marshalIpnsApiUpdateNameRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags,
  value: request.value
});
const marshalReplacePinRequest = (request, defaults) => ({
  cid: request.cid,
  name: request.name,
  origins: request.origins,
  volume_id: request.volumeId
});
const marshalUpdateVolumeRequest = (request, defaults) => ({
  name: request.name,
  tags: request.tags
});
export {
  marshalCreatePinByCIDRequest,
  marshalCreatePinByURLRequest,
  marshalCreateVolumeRequest,
  marshalIpnsApiCreateNameRequest,
  marshalIpnsApiImportKeyNameRequest,
  marshalIpnsApiUpdateNameRequest,
  marshalReplacePinRequest,
  marshalUpdateVolumeRequest,
  unmarshalExportKeyNameResponse,
  unmarshalListNamesResponse,
  unmarshalListPinsResponse,
  unmarshalListVolumesResponse,
  unmarshalName,
  unmarshalPin,
  unmarshalReplacePinResponse,
  unmarshalVolume
};
